@@ -1,6 +1,6 @@
 package Net::Cloudflare::DNS::Teal;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use 5.006;
 use strict;
@@ -122,8 +122,9 @@ sub teal {
 
 =head1 NAME
 
-Net::Cloudflare::DNS::Teal is a module intended to be used for 
-managing Blue/Green deployments in Cloudflare DNS.
+Net::Cloudflare::DNS::Teal - Makes your Blue/Green deployments in Cloudflare easy!
+
+This module is intended to be used for managing Blue/Green deployments in Cloudflare DNS.
 
 It's compatible with Cloudflare Pages, but can be used for wider range of use cases.
 (but then think about using a Cloudflare Load Balancer)
@@ -147,7 +148,7 @@ As of today, this module is NOT production ready.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
